*********************************************************
**** Doing A Meta-Analysis 						     ****
**** Author: Ola Uthman	   					         ****
**** University of Warwick						     ****
**** May 10, 2020						             ****
*********************************************************




************************************************************
*** 			          BINARY DATA                    ***
************************************************************

***STEP 1 - LOAD DATA

import excel  using data/magnedata.xlsx, firstrow


use data/magnedata.dta, clear

describe 


generate nodead1 = tot1 - dead1
generate nodead0 = tot0 - dead0
order trial trialnam year dead1 nodead1 dead0 nodead0

***STEP 2- DECLARE, UPDATE & DESCRIBE meta data
/*

Now, combine the results of trials, using the fixed effects model for crude data to calculate a summary estimate
Q1.1 - From a visual inspection of the forest plot generated by Stata, do the measures of outcome appear consistent across studies (just provide a qualitative/descriptive answer based on the data)?
Q1.2 - What is the summary estimate and 95% confidence interval?
Q1.3 - Which study is weighted the most heavily, and how does the point estimate for this study compare to the overall summary estimate?
Q1.4 - How would you interpret the results?
*/
meta esize dead1 nodead1 dead0 nodead0, studylabel(trialnam) esize(lnrratio)

***STEP 3- SUMMARIZE meta data by using a TABLE or a FOREST PLOT
meta summarize, fixed


meta forestplot, fixed

meta forestplot, nullrefline fixed eform

/*


OR combined the results using Random effects model.
Q1.5 - Do the summary estimate and 95% confidence interval differ from the fixed effects model?
Q1.6 - Compare the relative weights of the studies in the fixed effects model with their weights in the random effects model. Discuss how the relative weights affect the summary estimates and 95% confidence intervals.
*/
meta summarize, random
meta forestplot, nullrefline random
d


/*

Slide Type
In Stata, Q is labelled “Heterogeneity chi-squared.”
Q1.7 - Are the results homogeneous?
Q1.8 - What is heterogeneity and what factors can account for heterogeneity?
Q1.9 - Which trial(s) do you suspect contributes the most to heterogeneity in this analysis? Why?
*/

***STEP 4- EXPLORE HETEROGENEITY - SUB-GROUP and META-REGRESSION analysis

/*
Q1.10 - Does exclusion of this trial(s) “fix” the heterogeneity?
Q1.11 - What are the summary estimates for each group?
Q1.12 - Are the results homogeneous for each group?
*/
recode _meta_studysize (min/999 = 0 "Smaller RCTs") (1000/max = 1 "Mega-RCTs"), gen(size)



meta summarize, subgroup(size)


meta forestplot, subgroup(size)  nullrefline



/*
Fit a meta-regression model that explains the heterogeneity in terms of the study size category
Q1.13 - Is the study size statistically significant?
Q1.14 - What percentage of heterogeneity is explained by the study size
*/


meta regress size
meta regress year

estat bubbleplot

/*
Cumulative meta-analysis
Explore how the pooled result would have changed through time by using the cumulative meta-analysis command metacum
Q1.15 - What do you conclude?
*/
meta forestplot, cumulative(year) nullrefline

***STEP 5- EXPLORE and ADDRESS SMALL-STUDY EFFECTS
meta funnelplot

meta funnelplot, contours(1 5 10) 

meta bias, egger


meta trimfill


meta trimfill, eform funnel(contours(1 5 10))

















************************************************************
*** 			          GENERIC DATA                    ***
************************************************************

***STEP 1 - LOAD DATA

use data/exercise4deprsn.dta, clear

describe 

***STEP 2- DECLARE, UPDATE & DESCRIBE meta data

meta set smd sesmd, studylabel(study) eslabel(Std. Mean Diff.)



***STEP 3- SUMMARIZE meta data by using a TABLE or a FOREST PLOT

meta forestplot, nullrefline fixed

meta forestplot, nullrefline random

***STEP 4- EXPLORE HETEROGENEITY - SUB-GROUP and META-REGRESSION analysis

meta forestplot, nullrefline random subgroup(abstract)
meta forestplot, nullrefline random subgroup(itt)
meta forestplot, nullrefline random subgroup(alloc)
meta forestplot, nullrefline random subgroup(phd)

meta regress abstract
meta regress duration
estat bubbleplot
meta regress itt
meta regress alloc
meta regress phd

foreach factor of varlist abstract duration itt alloc phd {
	meta regress  `factor'
}

meta regress abstract duration



***STEP 5- EXPLORE and ADDRESS SMALL-STUDY EFFECTS
meta funnelplot, metric(invse)


meta bias, egger


meta trimfill






















************************************************************
*** 			      CONTINUOUS DATA                    ***
************************************************************

***STEP 1 - LOAD DATA

use data/cont_data.dta, clear

describe 


***STEP 2- DECLARE, UPDATE & DESCRIBE meta data

meta esize tsample tmean tsd csample cmean csd, studylabel(id) esize(hedgesg) 

***STEP 3- SUMMARIZE meta data by using a TABLE or a FOREST PLOT

meta forestplot, nullrefline 


meta update, esize(mdiff)

meta forestplot, nullrefline 

***STEP 4- EXPLORE HETEROGENEITY - SUB-GROUP and META-REGRESSION analysis


meta regress year



***STEP 5- EXPLORE and ADDRESS SMALL-STUDY EFFECTS
meta funnelplot



meta bias, egger


meta trimfill












************************************************************
*** 		PROPORTION/PREVALENCE.                       ***
************************************************************

***STEP 1 - LOAD DATA
*https://www.ncbi.nlm.nih.gov/pmc/articles/PMC7096724/
*Prevalence of Underlying Diseases in Hospitalized Patients with COVID-19: a Systematic Review and Meta-Analysis



use data/covid-premorb.dta, clear

describe 

***STEP 2- DECLARE, UPDATE & DESCRIBE meta data




***STEP 3- SUMMARIZE meta data by using a TABLE or a FOREST PLOT
metaprop r n, ftt random 
metaprop r n, ftt random label(namevar=study) 
metaprop r n, ftt random label(namevar=study) power(2)



***STEP 4- EXPLORE HETEROGENEITY - SUB-GROUP and META-REGRESSION analysis

metaprop r n, ftt random label(namevar=study) power(3) by(morb)


meta set _ES _seES, studylabel(study) eslabel(Premorb. Prevalence.)
meta regress male
estat bubbleplot


meta regress n
estat bubbleplot



***STEP 5- EXPLORE and ADDRESS SMALL-STUDY EFFECTS
meta funnelplot, metric(invse)


meta bias, egger


meta trimfill





